@@ -3,4 +3,4 @@
 #' This list stores the configuration used for new projects.
 #'
 #' @include translate.dcf.R
-new.config <- translate.dcf(system.file('defaults/config/global.dcf', package = 'ProjectTemplate'))
+new.config <- translate.dcf(system.file('defaults/full/config/global.dcf', package = 'ProjectTemplate'))
