@@ -21,15 +21,7 @@ test.project <- function()
   load.project()
   require.package('testthat', attach = TRUE)
 
-  files = dir('tests', full.names = TRUE)
-  # Versions of testhat <0.8.0 use global enclosure
-  # >0.8.0 use parent of global
-  # Need to call test_file appropriately
+  files = dir('tests', pattern = "[.][rR]$", full.names = TRUE)
 
-  if (packageVersion('testthat') < '0.8.0')
-  {
-    invisible(lapply(files, testthat::test_file))
-  } else {
-    invisible(lapply(files, testthat::test_file, env = environment()))
-  }
+  invisible(lapply(files, testthat::test_file, env = environment()))
 }
