@@ -1,10 +1,13 @@
 context('Configuration')
 
 test_that('Unknown fields give a warning, except if start with hash', {
-  create.project('test_project', minimal = TRUE)
-  setwd('test_project')
-  on.exit(setwd('..'), add = TRUE)
-  on.exit(unlink('test_project', recursive = TRUE), add = TRUE)
+
+  test_project <- tempfile('test_project')
+  suppressMessages(create.project(test_project, minimal = TRUE))
+  on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
+
+  oldwd <- setwd(test_project)
+  on.exit(setwd(oldwd), add = TRUE)
 
   config <- new.config
   config$dummy <- 'dummy'
@@ -18,5 +21,6 @@ test_that('Unknown fields give a warning, except if start with hash', {
   config.dcf <- c(config.dcf, "# comment: A comment",
                   "#: Yet another comment")
   writeLines(config.dcf, 'config/global.dcf')
-  expect_that(load.project(), not(gives_warning()))
+  expect_warning(load.project(), NA)
+
 })
