@@ -19,7 +19,7 @@ lapply(
       on.exit(.unload.project(), add = TRUE)
 
       expect_warning(suppressMessages(migrate.project()), "missing the following entries")
-      expect_that(suppressMessages(load.project()), not(gives_warning()))
+      expect_warning(suppressMessages(load.project()), NA)
       expect_defaults(get.project()$config)
     })
   }
