@@ -1,11 +1,13 @@
 context('Require package')
 
 test_that('.require.package warns if compat setting is set', {
-  suppressMessages(create.project('test_project', minimal = FALSE))
-  setwd('test_project')
 
-  on.exit(setwd('..'), add = TRUE)
-  on.exit(unlink('test_project', recursive = TRUE), add = TRUE)
+  test_project <- tempfile('test_project')
+  suppressMessages(create.project(test_project, minimal = FALSE))
+  on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
+
+  oldwd <- setwd(test_project)
+  on.exit(setwd(oldwd), add = TRUE)
 
   suppressMessages(.unload.project())
   expect_false(.has.project())
@@ -13,7 +15,7 @@ test_that('.require.package warns if compat setting is set', {
   expect_true(.has.project())
 
   expect_false(project.info$config$attach_internal_libraries)
-  expect_that(.require.package('ProjectTemplate'), not(gives_warning()))
+  expect_warning(.require.package('ProjectTemplate'), NA)
 
   project.info$config[['attach_internal_libraries']] <<- TRUE
   expect_true(project.info$config[['attach_internal_libraries']])
